@@ -15,7 +15,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.31.0"
+version = "1.33.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -24,7 +24,7 @@ apk_keys_path = pmb_src + "/pmb/data/keys"
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.5-r0",
+apk_tools_min_version = {"edge": "2.12.5-r1",
                          "v3.13": "2.12.5-r0",
                          "v3.12": "2.10.6-r0"}
 
@@ -79,7 +79,8 @@ defaults = {
     "ccache_size": "5G",
     "is_default_channel": True,
     "cipher": "aes-xts-plain64",
-    "config": (os.environ.get('XDG_CONFIG_HOME') or os.path.expanduser("~/.config")) + "/pmbootstrap.cfg",
+    "config": (os.environ.get('XDG_CONFIG_HOME') or
+               os.path.expanduser("~/.config")) + "/pmbootstrap.cfg",
     "device": "qemu-amd64",
     "extra_packages": "none",
     "fork_alpine": False,
@@ -263,6 +264,11 @@ necessary_kconfig_options = {
             "USER_NS": True,
         },
     },
+    "<4.7.0": {
+        "all": {
+            "DEVPTS_MULTIPLE_INSTANCES": True,
+        }
+    },
     "<5.2.0": {
         "armhf armv7 x86": {
             "LBDAF": True
@@ -296,6 +302,26 @@ necessary_kconfig_options_anbox = {
     },
 }
 
+# Necessary nftables kernel config options
+necessary_kconfig_options_nftables = {
+    ">=3.13.0": {  # nftables support introduced here
+        "all": {  # all arches
+            "NETFILTER": True,
+            "NF_TABLES": True,
+            "NFT_CT": True,
+            "NFT_COUNTER": True,
+            "NFT_LOG": True,
+            "NFT_LIMIT": True,
+            "NFT_MASQ": True,
+            "NFT_NAT": True,
+            "NF_TABLES_IPV4": True,
+            "NF_REJECT_IPV4": True,
+            "NF_TABLES_IPV6": True,
+            "NF_REJECT_IPV6": True,
+        }
+    },
+}
+
 #
 # PARSE
 #
@@ -363,6 +389,7 @@ apkbuild_custom_valid_options = [
     "!pmb:crossdirect",
     "!pmb:kconfig-check",
     "pmb:kconfigcheck-anbox",
+    "pmb:kconfigcheck-nftables",
     "pmb:cross-native",
     "pmb:strict",
 ]
@@ -421,6 +448,7 @@ deviceinfo_attributes = [
     "partition_blacklist",
     "boot_part_start",
     "root_filesystem",
+    "flash_kernel_on_update",
 
     # weston
     "weston_pixman_type",
@@ -515,10 +543,11 @@ flashers = {
                       "boot", "$BOOT/boot.img-$FLAVOR"]],
         },
     },
-    # Some devices provide Fastboot but using Android boot images is not practical
-    # for them (e.g. because they support booting from FAT32 partitions directly
-    # and/or the Android boot partition is too small). This can be implemented
-    # using --split (separate image files for boot and rootfs).
+    # Some devices provide Fastboot but using Android boot images is not
+    # practical for them (e.g. because they support booting from FAT32
+    # partitions directly and/or the Android boot partition is too small).
+    # This can be implemented using --split (separate image files for boot and
+    # rootfs).
     # This flasher allows flashing the split image files using Fastboot.
     "fastboot-bootpart": {
         "split": True,
@@ -561,7 +590,8 @@ flashers = {
                 ["heimdall", "flash", "--$PARTITION_SYSTEM", "$IMAGE"]],
             "flash_kernel": [
                 ["heimdall_wait_for_device.sh"],
-                ["heimdall", "flash", "--$PARTITION_KERNEL", "$BOOT/boot.img-$FLAVOR"]],
+                ["heimdall", "flash", "--$PARTITION_KERNEL",
+                 "$BOOT/boot.img-$FLAVOR"]],
             "flash_vbmeta": [
                 ["avbtool", "make_vbmeta_image", "--flags", "2",
                     "--padding_size", "$FLASH_PAGESIZE",
@@ -623,7 +653,7 @@ aportgen = {
 # generate a pmaport that wraps an apk from Alpine (e.g. musl-armv7) locally
 # with one up-to-date mirror given by the CDN. But then the build will fail if
 # CDN picks an outdated mirror for CI or BPO.
-aportgen_mirror_alpine = "http://dl-2.alpinelinux.org/alpine/"
+aportgen_mirror_alpine = "http://dl-4.alpinelinux.org/alpine/"
 
 #
 # NEWAPKBUILD
@@ -654,8 +684,10 @@ newapkbuild_arguments_switches_other = [
 #
 # UPGRADE
 #
-# Patterns of package names to ignore for automatic pmaport upgrading ("pmbootstrap aportupgrade --all")
-upgrade_ignore = ["device-*", "firmware-*", "linux-*", "postmarketos-*", "*-aarch64", "*-armhf", "*-armv7"]
+# Patterns of package names to ignore for automatic pmaport upgrading
+# ("pmbootstrap aportupgrade --all")
+upgrade_ignore = ["device-*", "firmware-*", "linux-*", "postmarketos-*",
+                  "*-aarch64", "*-armhf", "*-armv7"]
 
 #
 # SIDELOAD
