@@ -20,12 +20,13 @@ def load(args):
 
         # We used to save default values in the config, which can *not* be
         # configured in "pmbootstrap init". That doesn't make sense, we always
-        # want to use the defaults from pmb/config/__init__.py in that case, not
-        # some outdated version we saved some time back (eg. aports folder,
+        # want to use the defaults from pmb/config/__init__.py in that case,
+        # not some outdated version we saved some time back (eg. aports folder,
         # postmarketOS binary packages mirror).
         if key not in pmb.config.config_keys and key in cfg["pmbootstrap"]:
-            logging.debug("Ignored unconfigurable and possibly outdated default"
-                          " value from config: " + str(cfg["pmbootstrap"][key]))
+            logging.debug("Ignored unconfigurable and possibly outdated"
+                          " default value from config:"
+                          f" {cfg['pmbootstrap'][key]}")
             del cfg["pmbootstrap"][key]
 
     return cfg
