@@ -1,4 +1,4 @@
-# Copyright 2020 Oliver Smith
+# Copyright 2021 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 """
 Functions that work with binary package repos. See also:
@@ -179,7 +179,8 @@ def update(args, arch=None, force=False, existing_only=False):
                  " (" + str(len(outdated)) + " file(s))")
 
     # Download and move to right location
-    for url, target in outdated.items():
+    for (i, (url, target)) in enumerate(outdated.items()):
+        pmb.helpers.cli.progress_print(args, i / len(outdated))
         temp = pmb.helpers.http.download(args, url, "APKINDEX", False,
                                          logging.DEBUG, True)
         if not temp:
@@ -189,6 +190,7 @@ def update(args, arch=None, force=False, existing_only=False):
         if not os.path.exists(target_folder):
             pmb.helpers.run.root(args, ["mkdir", "-p", target_folder])
         pmb.helpers.run.root(args, ["cp", temp, target])
+    pmb.helpers.cli.progress_flush(args)
 
     return True
 
