@@ -53,6 +53,8 @@ def arguments_install(subparser):
     # Other arguments (that don't fit categories below)
     ret.add_argument("--no-sshd", action="store_true",
                      help="do not enable the SSH daemon by default")
+    ret.add_argument("--no-firewall", action="store_true",
+                     help="do not enable the firewall by default")
 
     # Image type
     group_desc = ret.add_argument_group(
@@ -185,6 +187,9 @@ def arguments_sideload(subparser):
     ret.add_argument("--host", help="ip of the device over wifi"
                                     " (defaults to 172.16.42.1)",
                      default="172.16.42.1")
+    ret.add_argument("--port", help="SSH port of the device over wifi"
+                                    " (defaults to 22)",
+                     default="22")
     ret.add_argument("--user", help="use a different username than the"
                      " one set in init")
     ret.add_argument("--arch", help="use a different architecture than the one"
@@ -315,8 +320,8 @@ def arguments_qemu(subparser):
 
     ret.add_argument("--display", dest="qemu_display",
                      choices=["sdl", "gtk", "none"],
-                     help="QEMU's display parameter (default: sdl,gl=on)",
-                     default="sdl", nargs="?")
+                     help="QEMU's display parameter (default: gtk,gl=on)",
+                     default="gtk", nargs="?")
     ret.add_argument("--no-gl", dest="qemu_gl", default=True,
                      action='store_false', help="Avoid using GL for"
                      " accelerating graphics in QEMU  (use software"
@@ -432,6 +437,8 @@ def arguments_kconfig(subparser):
                        " directly instead of a config in a package")
     check.add_argument("--anbox", action="store_true", help="check"
                        " options needed for anbox too")
+    check.add_argument("--nftables", action="store_true", help="check"
+                       " options needed for nftables too")
     check_package = check.add_argument("package", default="", nargs='?')
     if argcomplete:
         check_package.completer = kernel_completer
