@@ -65,18 +65,26 @@ def check_option(component, details, config, config_path_pretty, option,
 
 
 def check_config(config_path, config_path_pretty, config_arch, pkgver,
-                 anbox=False, details=False):
-    logging.debug("Check kconfig: " + config_path)
+                 anbox=False, nftables=False, details=False):
+    logging.debug(f"Check kconfig: {config_path}")
     with open(config_path) as handle:
         config = handle.read()
 
+    components = {"postmarketOS": pmb.config.necessary_kconfig_options}
     if anbox:
-        options = pmb.config.necessary_kconfig_options_anbox
-        component = "anbox"
-    else:
-        options = pmb.config.necessary_kconfig_options
-        component = "postmarketOS"
+        components["anbox"] = pmb.config.necessary_kconfig_options_anbox
+    if nftables:
+        components["nftables"] = pmb.config.necessary_kconfig_options_nftables
 
+    results = [check_config_options_set(config, config_path_pretty,
+                                        config_arch, options, component,
+                                        pkgver, details)
+               for component, options in components.items()]
+    return all(results)
+
+
+def check_config_options_set(config, config_path_pretty, config_arch, options,
+                             component, pkgver, details=False):
     # Loop through necessary config options, and print a warning,
     # if any is missing
     ret = True
@@ -103,7 +111,8 @@ def check_config(config_path, config_path_pretty, config_arch, pkgver,
     return ret
 
 
-def check(args, pkgname, force_anbox_check=False, details=False):
+def check(args, pkgname, force_anbox_check=False, force_nftables_check=False,
+          details=False):
     """
     Check for necessary kernel config options in a package.
 
@@ -124,16 +133,16 @@ def check(args, pkgname, force_anbox_check=False, details=False):
     pkgver = apkbuild["pkgver"]
     check_anbox = force_anbox_check or (
         "pmb:kconfigcheck-anbox" in apkbuild["options"])
+    check_nftables = force_nftables_check or (
+        "pmb:kconfigcheck-nftables" in apkbuild["options"])
     for config_path in glob.glob(aport + "/config-*"):
         # The architecture of the config is in the name, so it just needs to be
         # extracted
         config_arch = os.path.basename(config_path).split(".")[1]
         config_path_pretty = f"linux-{flavor}/{os.path.basename(config_path)}"
         ret &= check_config(config_path, config_path_pretty, config_arch,
-                            pkgver, details=details)
-        if check_anbox:
-            ret &= check_config(config_path, config_path_pretty, config_arch,
-                                pkgver, anbox=True, details=details)
+                            pkgver, anbox=check_anbox, nftables=check_nftables,
+                            details=details)
     return ret
 
 
@@ -169,7 +178,8 @@ def extract_version(config_file):
     return "unknown"
 
 
-def check_file(args, config_file, anbox=False, details=False):
+def check_file(args, config_file, anbox=False, nftables=False,
+               details=False):
     """
     Check for necessary kernel config options in a kconfig file.
 
@@ -179,9 +189,5 @@ def check_file(args, config_file, anbox=False, details=False):
     version = extract_version(config_file)
     logging.debug(f"Check kconfig: parsed arch={arch}, version={version} from "
                   "file: {config_file}")
-    ret = check_config(config_file, config_file, arch, version, anbox=False,
-                       details=details)
-    if anbox:
-        ret &= check_config(config_file, config_file, arch, version,
-                            anbox=True, details=details)
-    return ret
+    return check_config(config_file, config_file, arch, version,
+                        anbox=anbox, nftables=nftables, details=details)
